\name{adjwgt.fcn}
\alias{adjwgt.fcn}
\title{Adjust Initial Survey Design Weights}
\description{
  This function adjusts initial survey design weights when implementation results
  in use of oversample sites or when it is desired to have final weights sum to a
  known frame size.  Adjusted weights are equal to initial weight times the frame
  size divided by the sum of the initial weights.  The adjustment is done 
  separately for each category specified in argument wtcat.
}
\usage{
adjwgt.fcn(sites, wgt, wtcat, framesize)
}
\arguments{
  \item{sites}{the logical value for each site, where TRUE = include the site
    and FALSE = do not include the site.}
  \item{wgt}{the initial weight (inverse of the sample inclusion probability)
    for each site.}
  \item{wtcat}{the weight adjustment category name for each site.}
  \item{framesize}{the known size of the frame for each category name in 
    wtcat, which must have the names attribute set to match the category 
    names used in wtcat.}
}
\value{
  A vector of adjusted weights, where the adjusted weight is set to zero for 
  sites that have the logical value in the sites argument set to FALSE.
}
\author{Tony Olsen \email{Olsen.Tony@epa.gov}}
\examples{
sites <- as.logical(rep(rep(c("TRUE","FALSE"), c(9,1)), 5))
wgt <- runif(50, 10, 100)
wtcat <- rep(c("A","B"), c(30, 20))
framesize <- c(15, 10)
names(framesize) <- c("A","B")
adjwgt.fcn(sites, wgt, wtcat, framesize)
}
\keyword{survey}
\keyword{misc}

\eof
\name{cat.analysis.fcn}
\alias{cat.analysis.fcn}
\title{Categorical Data Analysis for Probability Survey Data}
\description{
  This function organizes input and output for analysis of catogorical data 
  generated by a probability survey.  Input can be either an object belonging to
  class "psurvey.analysis" (see the documentation for function psurvey.analysis.fcn)
  or through use of the other arguments to this function.
}
\usage{
cat.analysis.fcn(sites=NULL, subpop=NULL, design=NULL,
  data.cat=NULL, type.cat=NULL, N.cluster=NULL, popsize=NULL,
  stage1size=NULL, support=NULL, swgt=NULL, swgt1=NULL,
  unitsize=NULL, vartype="Local", conf=95, psurvey.obj=NULL)
}
\arguments{
  \item{sites}{a data frame consisting of two variables: the first variable is 
    site IDs, and the second variable is a logical vector indicating which
    sites to use in the analysis.  If psurvey.obj is not provided, then
    this argument is required.  The default is NULL.}
  \item{subpop}{a data frame describing sets of populations and subpopulations 
    for which estimates will be calculated.  The first variable is site  
    IDs.  Each subsequent variable identifies a Type of population, where
    the variable name is used to identify Type.  A Type variable
    identifies each site with one of the subpopulations of that Type.  If
    psurvey.obj is not provided, then this argument is required.  The
    default is NULL.}
  \item{design}{a data frame consisting of design variables.  If psurvey.obj is
    not provided, then this argument is required.  The default is NULL.
    Variables should be named as follows:\cr
       siteID = site IDs\cr
       wgt = final adjusted weights, which are either the weights for a
         single-stage sample or the stage two weights for a two-stage sample\cr
       xcoord = x-coordinates for location, which are either the x-coordinates
         for a single-stage sample or the stage two x-coordinates for a
         two-stage sample\cr
       ycoord = y-coordinates for location, which are either the y-coordinates
         for a single-stage sample or the stage two y-coordinates for a
         two-stage sample\cr
       stratum = the stratum codes\cr
       cluster = the stage one sampling unit (primary sampling unit or cluster)
         codes\cr
       wgt1 = final adjusted stage one weights\cr
       xcoord1 = the stage one x-coordinates for location\cr
       ycoord1 = the stage one y-coordinates for location}
  \item{data.cat}{a data frame of categorical response variables.  The first 
    variable is site IDs.  Subsequent variables are response variables.
    Missing data (NA) is allowed.  If psurvey.obj is not provided, then
    this argument is required.  The default is NULL.}
  \item{type.cat}{the type of categorical response variables, where "Status" = 
    site status and "Category" = resource category.  If this argument is
    not provided, then each response variable is assigned type "Category".
    The default is NULL.}
  \item{N.cluster}{the number of stage one sampling units in the resource, which 
    is required for calculation of finite and continuous population 
    correction factors for a two-stage sample.  For a stratified sample 
    this variable must be a vector containing a value for each stratum and
    must have the names attribute set to identify the stratum codes.  The
    default is NULL.}
  \item{popsize}{the known size of the resource - the total number of sampling 
    units of a discrete resource or the measure of a continuous resource,
    which is required for calculation of finite and continuous population 
    correction factors for a single-stage sample.  This variable is also 
    used to adjust estimators for the known size of a resource.  For a
    stratified sample this variable must be a vector containing a value 
    for each stratum and must have the names attribute set to identify the
    stratum codes.  The default is NULL.}
  \item{stage1size}{the known size of the stage one sampling units of a 
    two-stage sample, which is required for calculation of finite and  
    continuous population correction factors for a two-stage sample and 
    must have the names attribute set to identify the stage one sampling 
    unit codes.  For a stratified sample, the names attribute must be set
    to identify both stratum codes and stage one sampling unit codes using
    a convention where the two codes are separated by the # symbol, e.g.,
    "Stratum 1#Cluster 1".  The default is NULL.}
  \item{support}{the support value for each site - the value one (1) for a 
    site from a discrete resource or the measure of the sampling unit  
    associated with a site from a continuous resource, which is required  
    for calculation of finite and continuous population correction  
    factors.  The default is NULL.}
  \item{swgt}{the size-weight for each site, which is the stage two size-weight 
    for a two-stage sample.  The default is NULL.}
  \item{swgt1}{the stage one size-weight for each site.  The default is NULL.}
  \item{unitsize}{the known sum of the size-weights of the resource, which for a 
    stratified sample must be a vector containing a value for each stratum 
    and must have the names attribute set to identify the stratum codes.  
    The default is NULL.}
  \item{vartype}{the choice of variance estimator, where "Local" = local mean
    estimator and "SRS" = SRS estimator.  The default is "Local".}
  \item{conf}{the confidence level.  The default is 95\%.}
  \item{psurvey.obj}{a list of class psurvey.analysis that was produced by the
    function psurvey.analysis.fcn.  Depending on input to that function,
    some elements of the list may be NULL.  The default is NULL.}
}
\value{
  A data frame of population estimates for all combinations of subpopulation 
  Types, subpopulations within Types, response variables, and categories within 
  each response variable.  Estimates are calculated for proportion and size of 
  the population.  Standard error estimates and  confidence interval estimates 
  also are calculated.
}
\references{
  Diaz-Ramos, S., D.L. Stevens, Jr., and A.R. Olsen. (1996).  \emph{EMAP
  Statistical Methods Manual.} EPA/620/R-96/XXX.  Corvallis, OR: U.S.
  Environmental Protection Agency, Office of Research and Development, National
  Health Effects and Environmental Research Laboratory, Western Ecology
  Division.
}
\author{
Tony Olsen \email{Olsen.Tony@epa.gov}\cr
Tom Kincaid \email{Kincaid.Tom@epa.gov}
}
\seealso{
\code{\link{category.est.fcn}} 
}
\examples{
\dontshow{software.program <- "R"}
## Categorical variable example for two resource classes
mysiteID <- paste("Site", 1:100, sep="")
mysites <- data.frame(siteID=mysiteID, Active=rep(TRUE, 100))
mysubpop <- data.frame(siteID=mysiteID, Resource.Class=
  rep(c("A","B"), c(55,45)))
mydesign <- data.frame(siteID=mysiteID, wgt=runif(100, 10,
  100), xcoord=runif(100), ycoord=runif(100), stratum=
  rep(c("Stratum1", "Stratum2"), 50))
mydata.cat <- data.frame(siteID=mysiteID, CatVar=
  rep(c("north", "south", "east", "west"), 25))
cat.analysis.fcn(sites=mysites, subpop=mysubpop, design=mydesign,
   data.cat=mydata.cat)

## Exclude category \dQuote{south} from the analysis
mysites <- data.frame(siteID=mysiteID, Active=rep(c(TRUE,
   FALSE, TRUE, TRUE), 25))
cat.analysis.fcn(sites=mysites, subpop=mysubpop, design=
  mydesign, data.cat=mydata.cat)
}
\keyword{survey}
\keyword{univar}

\eof
\name{category.est.fcn}
\alias{category.est.fcn}
\title{Category Proportion and Total Estimates}
\description{
  This function estimates proportion (expressed as percent) and size of a
  resource in each of a set of categories and can also be used to estimate
  proportion and size for site status categories.  Upper and lower confidence
  bounds also are estimated.
}
\usage{
category.est.fcn(catvar, wgt, x=NULL, y=NULL, stratum=NULL,
  cluster=NULL, N.cluster=NULL, wgt1=NULL, x1=NULL, y1=NULL,
  popsize=NULL, stage1size=NULL, support=NULL, swgt=NULL,
  swgt1=NULL, unitsize=NULL, type="Category", vartype="Local",
  conf=95, check.ind = TRUE)
}
\arguments{
  \item{catvar}{the value of the categorical response variable or the site
    status for each site.}
  \item{wgt}{the final adjusted weight (inverse of the sample inclusion
    probability) for each site, which is either the weight for a 
    single-stage sample or the stage two weight for a two-stage sample.}
  \item{x}{x-coordinate for location for each site, which is either the
    x-coordinate for a single-stage sample or the stage two 
    x-coordinate for a two-stage sample.  The default is NULL.}
  \item{y}{y-coordinate for location for each site, which is either the
    y-coordinate for a single-stage sample or the stage two 
    y-coordinate for a two-stage sample.  The default is NULL.}
  \item{stratum}{the stratum for each site.  The default is NULL.}
  \item{cluster}{the stage one sampling unit (primary sampling unit or cluster) 
    code for each site.  The default is NULL.}
  \item{N.cluster}{the number of stage one sampling units in the resource, which 
    is required for calculation of finite and continuous population 
    correction factors for a two-stage sample.  For a stratified sample 
    this variable must be a vector containing a value for each stratum and
    must have the names attribute set to identify the stratum codes.  The
    default is NULL.}
  \item{wgt1}{the final adjusted stage one weight for each site.  The default
    is NULL.}
  \item{x1}{the stage one x-coordinate for location for each site.  The default
    is NULL.}
  \item{y1}{the stage one y-coordinate for location for each site.  The default
    is NULL.}
  \item{popsize}{the known size of the resource - the total number of sampling 
    units of a discrete resource or the measure of a continuous resource,
    which is required for calculation of finite and continuous population 
    correction factors for a single-stage sample.  This variable is also 
    used to adjust estimators for the known size of a resource.  For a
    stratified sample this variable must be a vector containing a value 
    for each stratum and must have the names attribute set to identify the
    stratum codes.  The default is NULL.}
  \item{stage1size}{the known size of the stage one sampling units of a two-
    stage sample, which is required for calculation of finite and  
    continuous population correction factors for a two-stage sample and 
    must have the names attribute set to identify the stage one sampling 
    unit codes.  For a stratified sample, the names attribute must be set
    to identify both stratum codes and stage one sampling unit codes using
    a convention where the two codes are separated by the # symbol, e.g.,
    "Stratum 1#Cluster 1".  The default is NULL.}
  \item{support}{the support value for each site - the value one (1) for a 
    site from a discrete resource or the measure of the sampling unit  
    associated with a site from a continuous resource, which is required  
    for calculation of finite and continuous population correction  
    factors.  The default is NULL.}
  \item{swgt}{the size-weight for each site, which is the stage two size-weight 
    for a two-stage sample.  The default is NULL.}
  \item{swgt1}{the stage one size-weight for each site.  The default is NULL.}
  \item{unitsize}{the known sum of the size-weights of the resource, which for a 
    stratified sample must be a vector containing a value for each stratum 
    and must have the names attribute set to identify the stratum codes.  
    The default is NULL.}
  \item{type}{the type of response variable, where "Status" = site status and
    "Category" = resource category.  The default is "Category".}
  \item{vartype}{the choice of variance estimator, where "Local" = local mean
    estimator and "SRS" = SRS estimator.  The default is "Local".}
  \item{conf}{the confidence level.  The default is 95\%.}
  \item{check.ind}{a logical value that indicates whether compatability
    checking of the input values is conducted, where TRUE = conduct 
    compatibility checking and FALSE = do not conduct compatibility 
    checking.  The default is TRUE.}
}
\details{
  Proportion estimates are calculated using the Horvitz-Thompson ratio estimator,
  i.e., the ratio of two Horvitz-Thompson estimators.  The numerator of the ratio
  estimates the size of the site status category.  The denominator of the ratio
  estimates the size of the resource.   Variance estimates for the proportion
  estimates are calculated using either the local mean variance estimator or the
  simple random sampling (SRS) variance estimator.  The choice of variance
  estimator is subject to user control.  The local mean variance estimator
  requires the x-coordinate and the y-coordinate of each site.  The
  SRS variance estimator uses the independent  random sample approximation
  to calculate joint inclusion probabilities.   Confidence bounds are calculated
  using a Normal distribution multiplier.  For a discrete resource size is
  the number of units in the resource.  For an extensive resource size is the 
  measure (extent) of the resource, i.e., length, area, or volume.  Size 
  estimates are calculated using the Horvitz- Thompson estimator.  Variance 
  estimates for the size estimates are calculated using either the local mean 
  variance estimator or the SRS variance estimator. The function can 
  accommodate a stratified sample.  For a stratified sample, separate estimates 
  and standard errors are calculated for each stratum, which are used to produce 
  estimates and standard errors for all strata combined.  Strata that contain a 
  single value are removed.  For a stratified sample, when either the size of the
  resource or the sum of the size-weights for the resource is provided for each 
  stratum, those values are used as  stratum weights for calculating the 
  estimates and standard errors for all strata combined.  In addition, when 
  either of those known values is provided for each stratum, size estimates are 
  obtained by multiplying the proportion estimate, i.e., the Horvitz-Thompson 
  ratio estimator, by the known value for the stratum.  For a stratified sample 
  when neither the size of the  resource nor the sum of the size-weights of the 
  resource is provided for  each stratum, estimated values are used as stratum 
  weights for calculating  the estimates and standard errors for all strata 
  combined.  The function can accomodate single-stage and two-stage samples for 
  both stratified and unstratified sampling designs.  Finite population and 
  continuous population correction factors can be utilized in variance 
  estimation.  The function checks for compatibility of input values and removes
  missing values.
}
\value{
  A list containing the following components:
  \item{Prop}{ a data frame containing the proportion estimates}
  \item{Size}{ a data frame containing the size estimates}
}
\references{
  Diaz-Ramos, S., D.L. Stevens, Jr., and A.R. Olsen. (1996).  \emph{EMAP
  Statistical Methods Manual.} EPA/620/R-96/XXX.  Corvallis, OR: U.S.
  Environmental Protection Agency, Office of Research and Development, National
  Health Effects and Environmental Research Laboratory, Western Ecology
  Division.
}
\author{Tom Kincaid \email{Kincaid.Tom@epa.gov}}
\examples{
catvar <- rep(c("north", "south", "east", "west"), rep(25, 4))
wgt <- runif(100, 10, 100)
category.est.fcn(catvar, wgt, vartype="SRS")

\dontshow{software.program <- "R"}
x <- runif(100)
y <- runif(100)
category.est.fcn(catvar, wgt, x, y)
}
\keyword{survey}
\keyword{univar}

\eof
\name{cdf.decon.fcn}
\alias{cdf.decon.fcn}
\title{Cumulative Distribution Function - Deconvolution}
\description{
  This function calculates an estimate of the deconvoluted cumulative 
  distribution function (CDF) for the proportion (expressed as percent) and 
  the total of a response variable, where the response variable may be defined
  for either a discrete or a continuous resource.  Optionally, for a discrete 
  resource, the size-weighted CDF can be calculated.  In addition the standard 
  error of the estimated CDF and confidence bounds are calculated.  The 
  simulation extrapolation deconvolution method (Stefanski and Bay, 1996) is
  used to deconvolute measurement error variance from the response.
}
\usage{
cdf.decon.fcn <- function(z, wgt, sigma, var.sigma=NULL,
  x=NULL, y=NULL, stratum=NULL, cluster=NULL, N.cluster=NULL,
  wgt1=NULL, x1=NULL, y1=NULL, popsize=NULL, stage1size=NULL,
  support=NULL, swgt=NULL, swgt1=NULL, unitsize=NULL,
  vartype="Local", conf=95, cdfval=NULL,
  pctval=c(5, 25, 50, 75, 95), check.ind=TRUE)
}
\arguments{
  \item{z}{the response value for each site.}
  \item{wgt}{the final adjusted weight (inverse of the sample inclusion
    probability) for each site, which is either the weight for a 
    single-stage sample or the stage two weight for a two-stage sample.}
  \item{sigma}{measurement error variance.}
  \item{var.sigma}{variance of the measurement error variance.  The default is
    NULL.}
  \item{x}{x-coordinate for location for each site, which is either the
    x-coordinate for a single-stage sample or the stage two 
    x-coordinate for a two-stage sample.  The default is NULL.}
  \item{y}{y-coordinate for location for each site, which is either the
    y-coordinate for a single-stage sample or the stage two 
    y-coordinate for a two-stage sample.  The default is NULL.}
  \item{stratum}{the stratum for each site.  The default is NULL.}
  \item{cluster}{the stage one sampling unit (primary sampling unit or cluster) 
    code for each site.  The default is NULL.}
  \item{N.cluster}{the number of stage one sampling units in the resource, which 
    is required for calculation of finite and continuous population 
    correction factors for a two-stage sample.  For a stratified sample 
    this variable must be a vector containing a value for each stratum and
    must have the names attribute set to identify the stratum codes.  The
    default is NULL.}
  \item{wgt1}{the final adjusted stage one weight for each site.  The default
    is NULL.}
  \item{x1}{the stage one x-coordinate for location for each site.  The default
    is NULL.}
  \item{y1}{the stage one y-coordinate for location for each site.  The default
    is NULL.}
  \item{popsize}{the known size of the resource - the total number of sampling 
    units of a discrete resource or the measure of a continuous resource,
    which is required for calculation of finite and continuous population 
    correction factors for a single-stage sample.  This variable is also 
    used to adjust estimators for the known size of a resource.  For a
    stratified sample this variable must be a vector containing a value 
    for each stratum and must have the names attribute set to identify the
    stratum codes.  The default is NULL.}
  \item{stage1size}{the known size of the stage one sampling units of a two-
    stage sample, which is required for calculation of finite and  
    continuous population correction factors for a two-stage sample and 
    must have the names attribute set to identify the stage one sampling 
    unit codes.  For a stratified sample, the names attribute must be set
    to identify both stratum codes and stage one sampling unit codes using
    a convention where the two codes are separated by the # symbol, e.g.,
    "Stratum 1#Cluster 1".  The default is NULL.}
  \item{support}{the support value for each site - the value one (1) for a 
    site from a discrete resource or the measure of the sampling unit  
    associated with a site from a continuous resource, which is required  
    for calculation of finite and continuous population correction  
    factors.  The default is NULL.}
  \item{swgt}{the size-weight for each site, which is the stage two size-weight 
    for a two-stage sample.  The default is NULL.}
  \item{swgt1}{the stage one size-weight for each site.  The default is NULL.}
  \item{unitsize}{the known sum of the size-weights of the resource, which for a 
    stratified sample must be a vector containing a value for each stratum 
    and must have the names attribute set to identify the stratum codes.  
    The default is NULL.}
  \item{vartype}{the choice of variance estimator, where "Local" = local mean
    estimator and "SRS" = SRS estimator.  The default is "Local".}
  \item{conf}{the confidence level.  The default is 95\%.}
  \item{cdfval}{the set of values at which the CDF is estimated.  If a set of
    values is not provided, then the sorted set of unique values of the
    response variable is used.  The default is NULL.}
  \item{pctval}{the set of values at which percentiles are estimated.  The
    default set is: {5, 25, 50, 75, 95}.}
  \item{check.ind}{a logical value that indicates whether compatability
    checking of the input values is conducted, where TRUE = conduct 
    compatibility checking and FALSE = do not conduct compatibility 
    checking.  The default is TRUE.}
}
\details{
  This function calculates an estimate of the deconvoluted cumulative 
  distribution function (CDF) for the proportion (expressed as percent) and the 
  total of a response  variable, where the response variable may be defined
  for either a discrete or a continuous resource.  Optionally, for a discrete 
  resource, the size-weighted CDF can be calculated.  In addition the standard 
  error of the estimated CDF and confidence bounds are calculated.  The 
  simulation extrapolation deconvolution method (Stefanski and Bay, 1996) is used 
  to deconvolute measurement error variance from the response.  The user
  can supply the set of values at which the CDF is estimated.  For the 
  CDF of a proportion, the Horvitz-Thompson ratio estimator, i.e., the
  ratio of two Horvitz-Thompson estimators, is used to calculate the CDF
  estimate.  For the CDF of a total, the user can supply the known size of
  the resource or the known sum of the size-weights of the resource, as
  appropriate.  For the CDF of a total when either the size of the
  resource or the sum of the size-weights of the resource is provided, the
  classic ratio estimator is used to calculate the CDF estimate, where
  that estimator is the product of the known value and the Horvitz-Thompson ratio
  estimator.   For the CDF of a total when neither the size of the
  resource nor the sum of the size-weights of the resource is provided, the
  Horvitz-Thompson estimator is used to calculate the CDF estimate.
  Variance estimates for the estimated CDF are calculated using either the
  local mean variance estimator or the simple random sampling (\code{SRS}) 
  variance estimator.  The choice of variance estimator is subject to user 
  control. The local mean variance estimator requires the \code{x}-coordinate and
  the \code{y}-coordinate of each site.  The \code{SRS} variance estimator uses
  the independent random sample approximation to calculate joint inclusion
  probabilities.  Confidence bounds are calculated using a \code{Normal}
  distribution multiplier.  In addition the function uses the estimated 
  CDF to calculate percentile estimates.  Estimated confidence bounds for
  the percentile estimates are calculated.  The user can supply the set of values
  for which percentiles estimates are desired.  Optionally, the user can use the
  default set of percentiles.  The function can accommodate a stratified sample.
  For a stratified sample, separate estimates and standard errors are calculated
  for each stratum, which are used to produce estimates and standard errors for
  all strata combined.  Strata that contain a single value are removed.  For a
  stratified sample, when either the size of the resource or the sum of the size-
  weights of the resource is provided for each stratum, those values are used as 
  stratum weights for calculating the estimates and standard  errors for all 
  strata combined.  For a stratified sample when neither the size of the resource
  nor the sum of the size-weights of the resource is provided for each stratum, 
  estimated values are used as stratum weights for calculating the estimates and 
  standard errors for all strata combined.   The function can accomodate 
  single-stage and two-stage samples for both stratified and unstratified 
  sampling designs.  Finite population and continuous population correction 
  factors can be utilized in variance estimation.  The function checks for 
  compatibility of input values and removes missing values.
}
\value{
  A list containing the following components:
  \item{CDF}{ a data frame containing the CDF estimates}
  \item{Pct}{ a data frame containing the percentile estimates}
}
\references{
  Diaz-Ramos, S., D.L. Stevens, Jr., and A.R. Olsen. (1996).  \emph{EMAP
  Statistical Methods Manual.} EPA/620/R-96/XXX.  Corvallis, OR: U.S.
  Environmental Protection Agency, Office of Research and Development, National
  Health Effects and Environmental Research Laboratory, Western Ecology
  Division.
}
\author{Tom Kincaid \email{Kincaid.Tom@epa.gov}}
\examples{
z <- rnorm(100, 10, 1)
wgt <- runif(100, 10, 100)
cdfval <- seq(min(z), max(z), length=20)
cdf.decon.fcn(z, wgt, sigma=0.25, var.sigma=0.1, vartype=
  "SRS", cdfval=cdfval)

\dontshow{software.program <- "R"}
x <- runif(100)
y <- runif(100)
cdf.decon.fcn(z, wgt, sigma=0.25, var.sigma=0.1, x, y, cdfval=
  cdfval)
}
\keyword{survey}
\keyword{distribution}

\eof
\name{cdf.est.fcn}
\alias{cdf.est.fcn}
\title{Cumulative Distribution Function - Estimation}
\description{
  This function calculates an estimate of the cumulative distribution function
  (CDF) for the proportion (expressed as percent) and the total of a response
  variable, where the response variable may be defined for either a discrete
  or a continuous resource.  Optionally, for a discrete resource, the
  size-weighted CDF can be calculated.  In addition the standard error of the
  estimated CDF and confidence bounds are calculated.
}
\usage{
cdf.est.fcn(z, wgt, x=NULL, y=NULL, stratum=NULL,
  cluster=NULL, N.cluster=NULL, wgt1=NULL, x1=NULL, y1=NULL,
  popsize=NULL, stage1size=NULL, support=NULL, swgt=NULL,
  swgt1=NULL, unitsize=NULL, vartype="Local", conf=95,
  cdfval=NULL, pctval=c(5, 25, 50, 75, 95), check.ind=TRUE)
}
\arguments{
  \item{z}{the response value for each site.}
  \item{wgt}{the final adjusted weight (inverse of the sample inclusion
    probability) for each site, which is either the weight for a 
    single-stage sample or the stage two weight for a two-stage sample.}
  \item{x}{x-coordinate for location for each site, which is either the
    x-coordinate for a single-stage sample or the stage two 
    x-coordinate for a two-stage sample.  The default is NULL.}
  \item{y}{y-coordinate for location for each site, which is either the
    y-coordinate for a single-stage sample or the stage two 
    y-coordinate for a two-stage sample.  The default is NULL.}
  \item{stratum}{the stratum for each site.  The default is NULL.}
  \item{cluster}{the stage one sampling unit (primary sampling unit or cluster) 
    code for each site.  The default is NULL.}
  \item{N.cluster}{the number of stage one sampling units in the resource, which 
    is required for calculation of finite and continuous population 
    correction factors for a two-stage sample.  For a stratified sample 
    this variable must be a vector containing a value for each stratum and
    must have the names attribute set to identify the stratum codes.  The
    default is NULL.}
  \item{wgt1}{the final adjusted stage one weight for each site.  The default
    is NULL.}
  \item{x1}{the stage one x-coordinate for location for each site.  The default
    is NULL.}
  \item{y1}{the stage one y-coordinate for location for each site.  The default
    is NULL.}
  \item{popsize}{the known size of the resource - the total number of sampling 
    units of a discrete resource or the measure of a continuous resource,
    which is required for calculation of finite and continuous population 
    correction factors for a single-stage sample.  This variable is also 
    used to adjust estimators for the known size of a resource.  For a
    stratified sample this variable must be a vector containing a value 
    for each stratum and must have the names attribute set to identify the
    stratum codes.  The default is NULL.}
  \item{stage1size}{the known size of the stage one sampling units of a two-
    stage sample, which is required for calculation of finite and  
    continuous population correction factors for a two-stage sample and 
    must have the names attribute set to identify the stage one sampling 
    unit codes.  For a stratified sample, the names attribute must be set
    to identify both stratum codes and stage one sampling unit codes using
    a convention where the two codes are separated by the # symbol, e.g.,
    "Stratum 1#Cluster 1".  The default is NULL.}
  \item{support}{the support value for each site - the value one (1) for a 
    site from a discrete resource or the measure of the sampling unit  
    associated with a site from a continuous resource, which is required  
    for calculation of finite and continuous population correction  
    factors.  The default is NULL.}
  \item{swgt}{the size-weight for each site, which is the stage two size-weight 
    for a two-stage sample.  The default is NULL.}
  \item{swgt1}{the stage one size-weight for each site.  The default is NULL.}
  \item{unitsize}{the known sum of the size-weights of the resource, which for a 
    stratified sample must be a vector containing a value for each stratum 
    and must have the names attribute set to identify the stratum codes.  
    The default is NULL.}
  \item{vartype}{the choice of variance estimator, where "Local" = local mean
    estimator and "SRS" = SRS estimator.  The default is "Local".}
  \item{conf}{the confidence level.  The default is 95\%.}
  \item{cdfval}{the set of values at which the CDF is estimated.  If a set of
    values is not provided, then the sorted set of unique values of the
    response variable is used.  The default is NULL.}
  \item{pctval}{the set of values at which percentiles are estimated.  The
    default set is: {5, 25, 50, 75, 95}.}
  \item{check.ind}{a logical value that indicates whether compatability
    checking of the input values is conducted, where TRUE = conduct 
    compatibility checking and FALSE = do not conduct compatibility 
    checking.  The default is TRUE.}
}
\details{
  This function calculates an estimate of the cumulative distribution function
  (CDF) for the proportion (expressed as percent) and the total of a
  response  variable, where the response variable may be defined for either a
  discrete or a continuous resource.  Optionally, for a discrete resource, the
  size-weighted CDF can be calculated.  In addition the standard error of
  the estimated CDF and confidence bounds are calculated.  The user
  can supply the set of values at which the CDF is estimated.  For the 
  CDF of a proportion, the Horvitz-Thompson ratio estimator, i.e., the
  ratio of two Horvitz-Thompson estimators, is used to calculate the CDF
  estimate.  For the CDF of a total, the user can supply the known size of
  the resource or the known sum of the size-weights of the resource, as
  appropriate.  For the CDF of a total when either the size of the
  resource or the sum of the size-weights of the resource is provided, the
  classic ratio estimator is used to calculate the CDF estimate, where
  that estimator is the product of the known value and the Horvitz-Thompson ratio
  estimator.   For the CDF of a total when neither the size of the
  resource nor the sum of the size-weights of the resource is provided, the
  Horvitz-Thompson estimator is used to calculate the CDF estimate.
  Variance estimates for the estimated CDF are calculated using either the
  local mean variance estimator or the simple random sampling (SRS) 
  variance estimator.  The choice of variance estimator is subject to user 
  control. The local mean variance estimator requires the x-coordinate and
  the y-coordinate of each site.  The SRS variance estimator uses
  the independent random sample approximation to calculate joint inclusion
  probabilities.  Confidence bounds are calculated using a Normal
  distribution multiplier.  In addition the function uses the estimated 
  CDF to calculate percentile estimates.  Estimated confidence bounds for
  the percentile estimates are calculated.  The user can supply the set of values
  for which percentiles estimates are desired.  Optionally, the user can use the
  default set of percentiles.  The function can accommodate a stratified sample.
  For a stratified sample, separate estimates and standard errors are calculated
  for each stratum, which are used to produce estimates and standard errors for
  all strata combined.  Strata that contain a single value are removed.  For a
  stratified sample, when either the size of the resource or the sum of the size-
  weights of the resource is provided for each stratum, those values are used as 
  stratum weights for calculating the estimates and standard  errors for all 
  strata combined.  For a stratified sample when neither the size of the resource
  nor the sum of the size-weights of the resource is provided for each stratum, 
  estimated values are used as stratum weights for calculating the estimates and 
  standard errors for all strata combined.   The function can accomodate 
  single-stage and two-stage samples for both stratified and unstratified 
  sampling designs.  Finite population and continuous population correction 
  factors can be utilized in variance estimation.  The function checks for 
  compatibility of input values and removes missing values.
}
\value{
  A list containing the following components:
  \item{CDF}{ a data frame containing the CDF estimates}
  \item{Pct}{ a data frame containing the percentile estimates}
}
\references{
  Diaz-Ramos, S., D.L. Stevens, Jr., and A.R. Olsen. (1996).  \emph{EMAP
  Statistical Methods Manual.} EPA/620/R-96/XXX.  Corvallis, OR: U.S.
  Environmental Protection Agency, Office of Research and Development, National
  Health Effects and Environmental Research Laboratory, Western Ecology
  Division.
}
\author{Tom Kincaid \email{Kincaid.Tom@epa.gov}}
\examples{
z <- rnorm(100, 10, 1)
wgt <- runif(100, 10, 100)
cdfval <- seq(min(z), max(z), length=20)
cdf.est.fcn(z, wgt, vartype="SRS", cdfval=cdfval)

\dontshow{software.program <- "R"}
x <- runif(100)
y <- runif(100)
cdf.est.fcn(z, wgt, x, y, cdfval=cdfval)
}
\keyword{survey}
\keyword{distribution}

\eof
\name{cdf.test.fcn}
\alias{cdf.test.fcn}
\title{Cumulative Distribution Function - Inference}
\description{
  This function calculates the Wald, Rao-Scott first order corrected (mean 
  eigenvalue corrected), and Rao-Scott second order corrected (Satterthwaite
  corrected) statistics for categorical data to test for differences between two
  cumulative distribution functions (CDFs).  The functions calculates both 
  standard versions of those three statistics, which are distributed as 
  Chi-squared random variables, plus modified version of the statistics, which 
  are distributed as F random variables.
}
\usage{
cdf.test.fcn(sample1, sample2, bounds, vartype="Local")
}
\arguments{
  \item{sample1}{the sample from the first population in the form of a list
    containing the following components:\cr
       z = the response value for each site\cr
       wgt = the final adjusted weight (inverse of the sample inclusion probability) for each site\cr
       x = x-coordinate for location for each site, which may be NULL\cr
       y = y-coordinate for location for each site, which may be NULL}
  \item{sample2}{the sample from the second population in the form of a list
    containing the following components:\cr
       z = the response value for each site\cr
       wgt = the final adjusted weight (inverse of the sample inclusion probability) for each site\cr
       x = x-coordinate for location for each site, which may be NULL\cr
       y = y-coordinate for location for each site, which may be NULL}
  \item{bounds}{upper bounds for calculating the classes for the CDF.}
  \item{vartype}{the choice of variance estimator, where "Local" = local mean
     estimator and "SRS" = SRS estimator.  The default is "Local".}
}
\details{
  The user supplies the set of upper bounds for defining the classes for the
  CDFs.  The Horvitz-Thompson ratio estimator, i.e., the ratio of two
  Horvitz-Thompson estimators, is used to calculate estimates of the class
  proportions for the CDFs.  Variance estimates for the test statistics are
  calculated using either the local mean variance estimator or the simple random
  sampling (SRS) variance estimator.  The choice of variance estimator is
  subject to user control.  The SRS variance estimator uses the
  independent random sample approximation to calculate joint inclusion
  probabilities.  The function checks for compatability of input values and
  removes missing values.}
\value{
  An object in data frame format containing the test statistic, degrees of 
  freedom (two values labeled Degrees of Freedom_1 and Degrees of  Freedom_2),
  and p value for the Wald, mean eigenvalue, and  Satterthwaite test procedures,
  which includes both Chi-squared distribution and F  distribution versions of 
  the procedures.  For the Chi-squared versions of  the test procedures, Degrees
  of Freedom_1 contains the relevant value  and Degrees of Freedom_2 is set to 
  missing (NA).  For the F-based  versions of the test procedures Degrees of 
  Freedom_1 contains the  numerator degrees of freedom and Degrees of Freedom_2
  contains the  denominator degrees of freedom.
}
\references{
  Kincaid, T.M. (2000). Testing for differences between cumulative distribution
  functions from complex environmental sampling surveys.  In \emph{2000
  Proceeding of the Section on Statistics and the Environment}, American
  Statistical Association, Alexandria, VA.
}
\author{Tom Kincaid \email{Kincaid.Tom@epa.gov}}
\examples{
z <- rnorm(100, 10, 1)
wgt <- runif(100, 10, 100)
sample1 <- list(z=z, wgt=wgt)
sample2 <- list(z=z+2, wgt=wgt)
bounds <- seq(min(sample1$z, sample2$z), max(sample1$z,
   sample2$z), length=4)[-1]
cdf.test.fcn(sample1, sample2, bounds, vartype="SRS")

\dontshow{software.program <- "R"}
x <- runif(100)
y <- runif(100)
sample1 <- list(z=z, wgt=wgt, x=x, y=y)
sample2 <- list(z=z+rnorm(100), wgt=wgt, x=x, y=y)
bounds <- seq(min(sample1$z, sample2$z), max(sample1$z,
   sample2$z), length=4)[-1]
cdf.test.fcn(sample1, sample2, bounds)
}
\keyword{survey}
\keyword{distribution}

\eof
\name{cont.analysis.fcn}
\alias{cont.analysis.fcn}
\title{Continuous Data Analysis for Probability Survey Data}
\description{
  This function organizes input and output for analysis of continuous data 
  generated by a probability survey.  Input can be either an object belonging to
  class "psurvey.analysis" (see the documentation for function psurvey.analysis.fcn)
  or through use of the other arguments to this function.
}
\usage{
cont.analysis.fcn(sites=NULL, subpop=NULL, design=NULL,
  data.cont=NULL, sigma=NULL, var.sigma=NULL, N.cluster=NULL,
  popsize=NULL, stage1size=NULL, support=NULL, swgt=NULL,
  swgt1=NULL, unitsize=NULL, vartype="Local", conf=95,
  pctval=c(5, 25, 50, 75, 95), psurvey.obj=NULL)
}
\arguments{
  \item{sites}{a data frame consisting of two variables: the first variable is 
    site IDs, and the second variable is a logical vector indicating which
    sites to use in the analysis.  If psurvey.obj is not provided, then
    this argument is required.  The default is NULL.}
  \item{subpop}{a data frame describing sets of populations and subpopulations 
    for which estimates will be calculated.  The first variable is site  
    IDs.  Each subsequent variable identifies a Type of population, where
    the variable name is used to identify Type.  A Type variable
    identifies each site with one of the subpopulations of that Type.  If
    psurvey.obj is not provided, then this argument is required.  The
    default is NULL.}
  \item{design}{a data frame consisting of design variables.  If psurvey.obj is
    not provided, then this argument is required.  The default is NULL.
    Variables should be named as follows:\cr
       siteID = site IDs\cr
       wgt = final adjusted weights, which are either the weights for a
         single-stage sample or the stage two weights for a two-stage sample\cr
       xcoord = x-coordinates for location, which are either the x-coordinates
         for a single-stage sample or the stage two x-coordinates for a
         two-stage sample\cr
       ycoord = y-coordinates for location, which are either the y-coordinates
         for a single-stage sample or the stage two y-coordinates for a
         two-stage sample\cr
       stratum = the stratum codes\cr
       cluster = the stage one sampling unit (primary sampling unit or cluster)
         codes\cr
       wgt1 = final adjusted stage one weights\cr
       xcoord1 = the stage one x-coordinates for location\cr
       ycoord1 = the stage one y-coordinates for location}
  \item{data.cont}{a data frame of continuous response variables.  The first 
    variable is site IDs.  Subsequent variables are response variables.
    Missing data (NA) is allowed.  If psurvey.obj is not provided, then
    this argument is required.  The default is NULL.}
  \item{sigma}{measurement error variance.  This variable must be a vector
    containing a value for each response variable and must have the names
    attribute set to identify the response variable names.  Missing data (NA)
    is allowed.  The default is NULL.}
  \item{var.sigma}{variance of the measurement error variance.  This variable
    must be a vector containing a value for each response variable and must have
    the names attribute set to identify the response variable names.  Missing
    data (NA) is allowed.  The default is NULL.}
  \item{N.cluster}{the number of stage one sampling units in the resource, which 
    is required for calculation of finite and continuous population 
    correction factors for a two-stage sample.  For a stratified sample 
    this variable must be a vector containing a value for each stratum and
    must have the names attribute set to identify the stratum codes.  The
    default is NULL.}
  \item{popsize}{the known size of the resource - the total number of sampling 
    units of a discrete resource or the measure of a continuous resource,
    which is required for calculation of finite and continuous population 
    correction factors for a single-stage sample.  This variable is also 
    used to adjust estimators for the known size of a resource.  For a
    stratified sample this variable must be a vector containing a value 
    for each stratum and must have the names attribute set to identify the
    stratum codes.  The default is NULL.}
  \item{stage1size}{the known size of the stage one sampling units of a two-
    stage sample, which is required for calculation of finite and  
    continuous population correction factors for a two-stage sample and 
    must have the names attribute set to identify the stage one sampling 
    unit codes.  For a stratified sample, the names attribute must be set
    to identify both stratum codes and stage one sampling unit codes using
    a convention where the two codes are separated by the # symbol, e.g.,
    "Stratum 1#Cluster 1".  The default is NULL.}
  \item{support}{the support value for each site - the value one (1) for a 
    site from a discrete resource or the measure of the sampling unit  
    associated with a site from a continuous resource, which is required  
    for calculation of finite and continuous population correction  
    factors.  The default is NULL.}
  \item{swgt}{the size-weight for each site, which is the stage two size-weight 
    for a two-stage sample.  The default is NULL.}
  \item{swgt1}{the stage one size-weight for each site.  The default is NULL.}
  \item{unitsize}{the known sum of the size-weights of the resource, which for a 
    stratified sample must be a vector containing a value for each stratum 
    and must have the names attribute set to identify the stratum codes.  
    The default is NULL.}
  \item{vartype}{the choice of variance estimator, where "Local" = local mean
    estimator and "SRS" = SRS estimator.  The default is "Local".}
  \item{conf}{the confidence level.  The default is 95\%.}
  \item{pctval}{the set of values at which percentiles are estimated.  The
    default set is: {5, 25, 50, 75, 95}.}
  \item{psurvey.obj}{A list of class psurvey.analysis that was produced by the
    function psurvey.analysis.fcn.  Depending on input to that function,
    some elements of the list may be NULL.  The default is NULL.}
}
\details{
  CDF estimates are calculated for all unique values of a response variable.
}
\value{
  A list containing either three or five data frames of population estimates for
  all combinations of population Types, subpopulations within Types, and
  response variables.  The data frames containing deconvoluted CDF estimates and
  deconvoluted percentile estimates are only included in the output list when an
  input value for measurement error variance is provided to the function.  CDF
  and percentile estimates are calculated for both proportion and size of the
  population.  Standard error estimates and confidence interval estimates also
  are calculated.  
  The five data frames are:
  \item{CDF}{ a data frame containing the CDF estimates.}
  \item{Pct}{ a data frame containing the percentile estimates.}
  \item{CDF.D}{ a data frame containing the deconvoluted CDF estimates.}
  \item{Pct.D}{ a data frame containing the deconvoluted percentile estimates.}
  \item{Tot}{ a data frame containing the total, mean, standard deviation, and 
    variance estimates.}
}
\references{
  Diaz-Ramos, S., D.L. Stevens, Jr., and A.R. Olsen. (1996).  \emph{EMAP
  Statistical Methods Manual.} EPA/620/R-96/XXX.  Corvallis, OR: U.S.
  Environmental Protection Agency, Office of Research and Development, National
  Health Effects and Environmental Research Laboratory, Western Ecology
  Division.
}
\author{
Tony Olsen \email{Olsen.Tony@epa.gov}\cr
Tom Kincaid \email{Kincaid.Tom@epa.gov}
}
\seealso{
\code{\link{cdf.est.fcn}, \link{total.est.fcn}} 
}
\examples{
\dontshow{software.program <- "R"}
## Continuous variable example
mysiteID <- paste("Site", 1:25, sep="")
mysites <- data.frame(siteID=mysiteID, Active=rep(TRUE, 25))
mysubpop <- data.frame(siteID=mysiteID, All.Sites=
  rep("All Sites",25))
mydesign <- data.frame(siteID=mysiteID, wgt=runif(25, 10,
  100), xcoord=runif(25), ycoord=runif(25))
ContVar <- rnorm(25, 10, 1)
mydata.cont <- data.frame(siteID=mysiteID, ContVar=ContVar)
cont.analysis.fcn(sites=mysites, subpop=mysubpop, design=
  mydesign, data.cont=mydata.cont)

## Include deconvolution estimates
mydata.cont <- data.frame(siteID=mysiteID, ContVar=ContVar,
   ContVar.1=ContVar + rnorm(25, 0, sqrt(0.25)),
   ContVar.2=ContVar + rnorm(25, 0, sqrt(0.50)))
mysigma <- c(NA, 0.25, 0.50)
names(mysigma) <- c("ContVar", "ContVar.1", "ContVar.2")
cont.analysis.fcn(sites=mysites, subpop=mysubpop, design=
  mydesign, data.cont=mydata.cont, sigma=mysigma)
}
\keyword{survey}
\keyword{distribution}
\keyword{univar}

\eof
\name{marinus}
\alias{marinus}
\title{Convert Coordinates from Latitude/Longitude to the Equidistant, Cylindric Map Projection}
\description{
  This function converts x,y coordinates measured in units of latitude and 
  longitude, i.e., geographic coordinates measured in decimal degrees, to 
  coordinates in the equidistant, cylindric map projection measured in units of
  kilometers.  The projection center is defined as the midpoint in latitude-
  longitude space.  The map projection is here named after Marinus of Tyre.
}
\usage{
marinus(lat, lon)
}
\arguments{
  \item{lat}{vector of latitudes.}
  \item{lon}{vector of longitudes.}
}
\value{
  A matrix with column names "x" and "y" containing the x and y coordinates 
  in the equidistant, cylindric map projection measured in units of kilometers.
}
\references{
  J.P. Snyder. USGS Prof. Paper 1395, p. 90.
}
\author{Denis White \email{White.Denis@epa.gov}}
\examples{
lat <- 45 + runif(100, -5, 5)
lon <- 120 + runif(100, -10, 10)
marinus(lat, lon)
}
\keyword{misc}

\eof
\name{psurvey.analysis-internal}
\alias{dframe.check.fcn}
\alias{input.check.fcn}
\alias{vecprint.fcn}
\alias{uniqueID.fcn}
\alias{catvar.prop.fcn}
\alias{catvar.size.fcn}
\alias{cdf.nresp.fcn}
\alias{cdf.prop.fcn}
\alias{cdf.total.fcn}
\alias{cdf.size.prop.fcn}
\alias{cdf.size.total.fcn}
\alias{cdfvar.prop.fcn}
\alias{cdfvar.total.fcn}
\alias{cdfvar.size.prop.fcn}
\alias{cdfvar.size.total.fcn}
\alias{simex.fcn}
\alias{dcdf.prop.fcn}
\alias{dcdf.total.fcn}
\alias{dcdf.size.prop.fcn}
\alias{dcdf.size.total.fcn}
\alias{dcdfvar.prop.fcn}
\alias{dcdfvar.total.fcn}
\alias{dcdfvar.size.prop.fcn}
\alias{dcdfvar.size.total.fcn}
\alias{isotonic.fcn}
\alias{sorted.fcn}
\alias{cdfvar.test.fcn}
\alias{total.var.fcn}
\alias{localmean.weight.fcn}
\alias{localmean.var.fcn}
\alias{localmean.cov.fcn}
\alias{localmean.df.fcn}
\alias{dist2full.fcn}
\alias{wnas.fcn}
\alias{format.fcn}
\title{Internal Psurvey.Analysis Functions}
\description{
  These functions are internal psurvey.analysis functions.
}
\usage{
dframe.check.fcn(nresp, siteID, sites, subpop, data.cat,
  type.cat, data.cont, design.names)
input.check.fcn(nresp, wgt, sigma, var.sigma, xcoord, ycoord,
  stratum.ind, stratum, stratum.levels, nstrata, cluster.ind,
  cluster, cluster.levels, ncluster, N.cluster, wgt1, xcoord1,
  ycoord1, popsize, stage1size, pcfactor.ind, support,
  swgt.ind, swgt, swgt1, unitsize, vartype, conf, cdfval=NULL,
  pctval=NULL)
vecprint.fcn(x, n.char=78)
uniqueID.fcn(x)
catvar.prop.fcn(z, wgt, x, y, prop, stratum.ind, stratum.level,
  cluster.ind, cluster, N.cluster, wgt1, x1, y1, popsize,
  pcfactor.ind, stage1size, support, vartype)
catvar.size.fcn(z, wgt, x, y, size, stratum.ind, stratum.level,
  cluster.ind, cluster, N.cluster, wgt1, x1, y1, popsize,
  pcfactor.ind, stage1size, support, vartype)
cdf.nresp.fcn(z, val)
cdf.prop.fcn(z, wgt, val, cluster.ind, cluster, wgt1)
cdf.total.fcn(z, wgt, val, cluster.ind, cluster, wgt1, popsize)
cdf.size.prop.fcn(z, wgt, swgt, val, cluster.ind, cluster,
  wgt1, swgt1)
cdf.size.total.fcn(z, wgt, swgt, val, cluster.ind, cluster, 
  wgt1, swgt1, unitsize)
cdfvar.prop.fcn(z, wgt, x, y, val, cdfest, stratum.ind,
  stratum.level, cluster.ind, cluster, N.cluster, wgt1, x1,
  y1, popsize, pcfactor.ind, stage1size, support, vartype)
cdfvar.total.fcn(z, wgt, x, y, val, cdfest, stratum.ind,
  stratum.level, cluster.ind, cluster, N.cluster, wgt1, x1,
  y1, popsize, pcfactor.ind, stage1size, support, vartype)
cdfvar.size.prop.fcn(z, wgt, x, y, val, cdfest, stratum.ind,
  stratum.level, cluster.ind, cluster, N.cluster, wgt1, x1,
  y1, popsize, pcfactor.ind, stage1size, support, swgt, swgt1,
  vartype)
cdfvar.size.total.fcn(z, wgt, x, y, val, cdfest, stratum.ind,
  stratum.level, cluster.ind, cluster, N.cluster, wgt1, x1,
  y1, popsize, pcfactor.ind, stage1size, support, swgt, swgt1,
  unitsize, vartype)
cdfvar.test.fcn (sampl, bounds, vartype)
simex.fcn(z, val, sigma, var.sigma, cluster.ind, cluster)
dcdf.prop.fcn(g, wgt, cluster.ind, cluster, wgt1)
dcdf.total.fcn(g, wgt, cluster.ind, cluster, wgt1, popsize)
dcdf.size.prop.fcn(g, wgt, swgt, cluster.ind, cluster, wgt1,
  swgt1)
dcdf.size.total.fcn(g, wgt, swgt, cluster.ind, cluster, wgt1,
  swgt1, unitsize)
dcdfvar.prop.fcn(g, dg, var.sigma, wgt, x, y, cdfest,
   stratum.ind, stratum.level, cluster.ind, cluster,
   N.cluster, wgt1, x1, y1, popsize, pcfactor.ind, stage1size,
   support, vartype)
dcdfvar.total.fcn(g, dg, var.sigma, wgt, x, y, cdfest,
   stratum.ind, stratum.level, cluster.ind, cluster,
   N.cluster, wgt1, x1, y1, popsize, pcfactor.ind, stage1size,
   support, vartype)
dcdfvar.size.prop.fcn(g, dg, var.sigma, wgt, x, y, cdfest,
   stratum.ind, stratum.level, cluster.ind, cluster,
   N.cluster, wgt1, x1, y1, popsize, pcfactor.ind, stage1size,
   support, swgt, swgt1, vartype)
dcdfvar.size.total.fcn(g, dg, var.sigma, wgt, x, y, cdfest,
   stratum.ind, stratum.level, cluster.ind, cluster,
   N.cluster, wgt1, x1, y1, popsize, pcfactor.ind, stage1size,
   support, swgt, swgt1, unitsize, vartype)
isotonic.fcn(y, minval, maxval)
sorted.fcn(x)
total.var.fcn (z, wgt, x, y, mean.est, var.est, sd.est,
  stratum.ind, stratum.level, cluster.ind, cluster, N.cluster,
  wgt1, x1, y1, popsize, pcfactor.ind, stage1size, support,
  vartype)
localmean.weight.fcn(x, y, prb, nbh)
localmean.var.fcn(z, weight.lst)
localmean.cov.fcn(zmat, weight.lst)
localmean.df.fcn(weight.lst)
dist2full.fcn(dis)
wnas.fcn(data)
format.fcn(x, n.digits, miss)
}
\details{
  These functions are not to be called by the user.
}
\author{Tom Kincaid \email{Kincaid.Tom@epa.gov}}
\keyword{internal}

\eof
\name{psurvey.analysis.fcn}
\alias{psurvey.analysis.fcn}
\title{Create an Object of Class psurvey.analysis}
\description{
  This function creates an object of class psurvey.analysis that contains all 
  of the information necessary to use the analysis functions in the 
  psurvey.analysis library.
}
\usage{
psurvey.analysis.fcn(sites=NULL, subpop=NULL, design=NULL,
  data.cat=NULL, type.cat=NULL, data.cont=NULL, siteID=NULL,
  wgt=NULL, sigma=NULL, var.sigma=NULL, xcoord=NULL,
  ycoord=NULL, stratum=NULL, cluster=NULL, N.cluster=NULL,
  wgt1=NULL, xcoord1=NULL, ycoord1=NULL, popsize=NULL,
  stage1size=NULL, support=NULL, swgt=NULL, swgt1=NULL,
  unitsize=NULL, vartype="Local", conf=95,
  pctval=c(5, 25, 50, 75, 95))
}
\arguments{
  \item{sites}{a data frame consisting of two variables: the first variable is 
    site IDs and the second variable is a logical vector indicating which 
    sites to use in the analysis.  If this data frame is not provided,  
    then the data frame will be created, where (1) site IDs are obtained  
    either from the design argument, the siteID argument, or both (when  
    siteID is a formula); and (2) all sites will be used in the analysis.  
    The default is NULL.}
  \item{subpop}{a data frame describing sets of populations and subpopulations 
    for which estimates will be calculated.  The first variable is site  
    IDs and each subsequent variable identifies a Type of population,  
    where the variable name is used to identify Type.  A Type variable  
    identifies each site with one of the subpopulations of that Type.  If   
    this data frame is not provided, then the data frame will be created,  
    where (1) site IDs are obtained either from the design argument, the  
    siteID argument, or both (when siteID is a formula); and (2) a single  
    Type variable named All.Sites that consists of all sites will be  
    created.  The default is NULL.}
  \item{design}{a data frame consisting of design variables.  If variable names 
    are provided as formulas in the corresponding arguments, then the 
    formulas are interpreted using this data frame.  If this data frame is 
    not provided, then the data frame will be created from inputs to the 
    design variables in the argument list.  The default is NULL.  If 
    variable names are not provided as formulas, then variables should be 
    named as follows:\cr
       siteID = site IDs\cr
       wgt = final adjusted weights, which are either the weights for a
         single-stage sample or the stage two weights for a two-stage sample\cr
       xcoord = x-coordinates for location, which are either the x-coordinates
         for a single-stage sample or the stage two x-coordinates for a
         two-stage sample\cr
       ycoord = y-coordinates for location, which are either the y-coordinates
         for a single-stage sample or the stage two y-coordinates for a
         two-stage sample\cr
       stratum = the stratum codes\cr
       cluster = the stage one sampling unit (primary sampling unit or cluster)
         codes\cr
       wgt1 = final adjusted stage one weights\cr
       xcoord1 = the stage one x-coordinates for location\cr
       ycoord1 = the stage one y-coordinates for location}
  \item{data.cat}{a data frame of categorical response variables.  The first 
    variable is site IDs.  Subsequent variables are response variables.
    Missing data (NA) is allowed.  If psurvey.obj is not provided, then
    this argument is required.  The default is NULL.}
  \item{type.cat}{the type of categorical response variables, where "Status" = 
    site status and "Category" = resource category.  If this argument is
    not provided, then each response variable is assigned type "Category".
    The default is NULL.}
  \item{data.cont}{a data frame of continuous response variables.  The first 
    variable is site IDs.  Subsequent variables are response variables.
    Missing data (NA) is allowed.  If psurvey.obj is not provided, then
    this argument is required.  The default is NULL.}
  \item{siteID}{site IDs.  This variable can be input directly or as a formula 
    and must be supplied either as this argument or in the design data 
    frame.  The default is NULL.}
  \item{wgt}{the final adjusted weight (inverse of the sample inclusion
    probability) for each site, which is either the weight for a 
    single-stage sample or the stage two weight for a two-stage sample.
    The default is NULL.}
  \item{sigma}{measurement error variance.  This variable must be a vector
    containing a value for each response variable and must have the names
    attribute set to identify the response variable names.  Missing data (NA)
    is allowed.  The default is NULL.}
  \item{var.sigma}{variance of the measurement error variance.  This variable
    must be a vector containing a value for each response variable and must have
    the names attribute set to identify the response variable names.  Missing
    data (NA) is allowed.  The default is NULL.}
  \item{xcoord}{x-coordinate for location for each site, which is either the
    x-coordinate for a single-stage sample or the stage two 
    x-coordinate for a two-stage sample.  The default is NULL.}
  \item{ycoord}{y-coordinate for location for each site, which is either the
    y-coordinate for a single-stage sample or the stage two 
    y-coordinate for a two-stage sample.  The default is NULL.}
  \item{stratum}{the stratum codes.  This variable can be input directly or as a 
    formula.  The default is NULL.}
  \item{cluster}{the stage one sampling unit (primary sampling unit or cluster) 
    codes.  This variable can be input directly or as a formula.  The 
    default is NULL.}
  \item{N.cluster}{the number of stage one sampling units in the resource, which 
    is required for calculation of finite and continuous population 
    correction factors for a two-stage sample.  For a stratified sample 
    this variable must be a vector containing a value for each stratum and
    must have the names attribute set to identify the stratum codes.  The
    default is NULL.}
  \item{wgt1}{the final adjusted stage one weights.  This variable can be input 
    directly or as a formula.  The default is NULL.}
  \item{xcoord1}{the stage one x-coordinates for location.  This variable can be 
    input directly or as a formula.  The default is NULL.}
  \item{ycoord1}{the stage one y-coordinates for location.  This variable can be 
    input directly or as a formula.  The default is NULL.}
  \item{popsize}{the known size of the resource - the total number of sampling 
    units of a discrete resource or the measure of a continuous resource,
    which is required for calculation of finite and continuous population 
    correction factors for a single-stage sample.  This variable is also 
    used to adjust estimators for the known size of a resource.  For a
    stratified sample this variable must be a vector containing a value 
    for each stratum and must have the names attribute set to identify the
    stratum codes.  The default is NULL.}
  \item{stage1size}{the known size of the stage one sampling units of a two-
    stage sample, which is required for calculation of finite and  
    continuous population correction factors for a two-stage sample and 
    must have the names attribute set to identify the stage one sampling 
    unit codes.  For a stratified sample, the names attribute must be set
    to identify both stratum codes and stage one sampling unit codes using
    a convention where the two codes are separated by the # symbol, e.g.,
    "Stratum 1#Cluster 1".  The default is NULL.}
  \item{support}{the support value for each site - the value one (1) for a 
    site from a discrete resource or the measure of the sampling unit  
    associated with a site from a continuous resource, which is required  
    for calculation of finite and continuous population correction  
    factors.  The default is NULL.}
  \item{swgt}{the size-weight for each site, which is the stage two size-weight 
    for a two-stage sample.  The default is NULL.}
  \item{swgt1}{the stage one size-weight for each site.  The default is NULL.}
  \item{unitsize}{the known sum of the size-weights of the resource, which for a 
    stratified sample must be a vector containing a value for each stratum 
    and must have the names attribute set to identify the stratum codes.  
    The default is NULL.}
  \item{vartype}{the choice of variance estimator, where "Local" = local mean
    estimator and "SRS" = SRS estimator.  The default is "Local".}
  \item{conf}{the confidence level.  The default is 95\%.}
  \item{pctval}{the set of values at which percentiles are estimated.  The 
    default set is: {5, 25, 50, 75, 95}.}
}
\value{
  A list of class psurvey.analysis.  Only those sites indicated by the 
  logical variable in the sites data frame are retained in the output. The
  sites, subpop, and design data frames will always exist in the output. At 
  least one of the data.cat and data.cont data frames will exist.  Depending
  upon values of the input variables, other elements in the output may be 
  NULL.  The output list is composed of the following elements:
  \item{sites}{ the sites data frame.}
  \item{subpop}{ the subpop data frame.}
  \item{design}{ the design data frame.}
  \item{data.cat}{ the data.cat data frame.}
  \item{type.cat}{ the type of categorical response variables.}
  \item{data.cont}{ the data.cont data frame.}
  \item{N.cluster}{ the number of stage one sampling units in the resource.} 
  \item{popsize}{ the known size of the resource.}
  \item{stage1size}{ the known size of the stage one sampling units.}
  \item{support}{ the support for each sampling unit.}
  \item{swgt}{ the size-weight for each site.}
  \item{swgt1}{ the stage one size-weight for each site.}
  \item{unitsize}{ the known sum of the size-weights of the resource}
  \item{stratum.ind}{ a logical value that indicates whether the sample is
     stratified, where TRUE = a stratified sample and FALSE = not a stratified
     sample.}
  \item{cluster.ind}{ a logical value that indicates whether the sample is a
     two-stage sample, where TRUE = a two-stage sample and FALSE = not a
     two-stage sample.}
  \item{pcfactor.ind}{ a logical value that indicates whether the population
     correction factor is used during variance estimation, where TRUE = use the
     population correction factor and FALSE = do not use the factor.}
  \item{swgt.ind}{ a logical value that indicates whether the sample is a
     size-weighted sample, where TRUE = a size-weighted sample and FALSE = not a
     size-weighted sample.}
  \item{vartype}{ the choice of variance estimator, where "Local" = local mean
     estimator and "SRS" = SRS estimator.}
  \item{conf}{ the confidence level}
  \item{pctval}{the set of values at which percentiles are estimated.  The
    default set is: {5, 25, 50, 75, 95}.}
}
\references{
  Diaz-Ramos, S., D.L. Stevens, Jr., and A.R. Olsen. (1996).  \emph{EMAP
  Statistical Methods Manual.} EPA/620/R-96/XXX.  Corvallis, OR: U.S.
  Environmental Protection Agency, Office of Research and Development, National
  Health Effects and Environmental Research Laboratory, Western Ecology
  Division.
}
\author{Tom Kincaid \email{Kincaid.Tom@epa.gov}}
\seealso{
\code{\link{cat.analysis.fcn}, \link{cont.analysis.fcn}} 
}
\examples{
\dontshow{software.program <- "R"}
## Categorical variable example
mysiteID <- paste("Site", 1:100, sep="")
mysites <- data.frame(siteID=mysiteID, Active=rep(c(TRUE,
  FALSE, TRUE, TRUE), 25))
mysubpop <- data.frame(siteID=mysiteID, Resource.Class=
  rep(c("A","B"), c(55,45)))
mydesign <- data.frame(siteID=mysiteID, wgt=runif(100, 10,
  100), xcoord=runif(100), ycoord=runif(100), stratum=
  rep(c("Stratum1", "Stratum2"), 50))
mydata.cat <- data.frame(siteID=mysiteID, CatVar=
  rep(c("north", "south", "east", "west"), 25))
psurvey.analysis.fcn(design=mydesign, data.cat=mydata.cat,
   vartype="SRS")

## Continuous variable example - including deconvolution estimates
mydesign <- data.frame(mysites=mysiteID[1:25], wgt=runif(25,
  10, 100), xcoord=runif(25), ycoord=runif(25))
ContVar <- rnorm(25, 10, 1)
mydata.cont <- data.frame(siteID=mysiteID[1:25], ContVar=ContVar,
   ContVar.1=ContVar + rnorm(25, 0, sqrt(0.25)),
   ContVar.2=ContVar + rnorm(25, 0, sqrt(0.50)))
mysigma <- c(NA, 0.25, 0.50)
names(mysigma) <- c("ContVar", "ContVar.1", "ContVar.2")
psurvey.analysis.fcn(design=mydesign, siteID=~mysites,
   data.cont=mydata.cont, sigma=mysigma)
}
\keyword{survey}

\eof
\name{total.est.fcn}
\alias{total.est.fcn}
\title{Population Total, Mean, Variance, and Standard Deviation}
\description{
  This function calculates estimates of the population total, mean, variance, and
  standard deviation of a response variable, where the response variable may be
  defined for either a discrete or an extensive resource.  In addition the 
  standard error of the population estimates and confidence bounds are
  calculated.
}
\usage{
total.est.fcn(z, wgt, x=NULL, y=NULL, stratum=NULL,
  cluster=NULL, N.cluster=NULL, wgt1=NULL, x1=NULL, y1=NULL,
  popsize=NULL, stage1size=NULL, support=NULL, swgt=NULL,
  swgt1=NULL, unitsize=NULL, vartype="Local", conf=95,
  check.ind=TRUE)
}
\arguments{
  \item{z}{the response value for each site.}
  \item{wgt}{the final adjusted weight (inverse of the sample inclusion
    probability) for each site, which is either the weight for a 
    single-stage sample or the stage two weight for a two-stage sample.}
  \item{x}{x-coordinate for location for each site, which is either the
    x-coordinate for a single-stage sample or the stage two 
    x-coordinate for a two-stage sample.  The default is NULL.}
  \item{y}{y-coordinate for location for each site, which is either the
    y-coordinate for a single-stage sample or the stage two 
    y-coordinate for a two-stage sample.  The default is NULL.}
  \item{stratum}{the stratum for each site.  The default is NULL.}
  \item{cluster}{the stage one sampling unit (primary sampling unit or cluster) 
    code for each site.  The default is NULL.}
  \item{N.cluster}{the number of stage one sampling units in the resource, which 
    is required for calculation of finite and continuous population 
    correction factors for a two-stage sample.  For a stratified sample 
    this variable must be a vector containing a value for each stratum and
    must have the names attribute set to identify the stratum codes.  The
    default is NULL.}
  \item{wgt1}{the final adjusted stage one weight for each site.  The default
    is NULL.}
  \item{x1}{the stage one x-coordinate for location for each site.  The default
    is NULL.}
  \item{y1}{the stage one y-coordinate for location for each site.  The default
    is NULL.}
  \item{popsize}{the known size of the resource - the total number of sampling 
    units of a discrete resource or the measure of a continuous resource,
    which is required for calculation of finite and continuous population 
    correction factors for a single-stage sample.  This variable is also 
    used to adjust estimators for the known size of a resource.  For a
    stratified sample this variable must be a vector containing a value 
    for each stratum and must have the names attribute set to identify the
    stratum codes.  The default is NULL.}
  \item{stage1size}{the known size of the stage one sampling units of a two-
    stage sample, which is required for calculation of finite and  
    continuous population correction factors for a two-stage sample and 
    must have the names attribute set to identify the stage one sampling 
    unit codes.  For a stratified sample, the names attribute must be set
    to identify both stratum codes and stage one sampling unit codes using
    a convention where the two codes are separated by the # symbol, e.g.,
    "Stratum 1#Cluster 1".  The default is NULL.}
  \item{support}{the support value for each site - the value one (1) for a 
    site from a discrete resource or the measure of the sampling unit  
    associated with a site from a continuous resource, which is required  
    for calculation of finite and continuous population correction  
    factors.  The default is NULL.}
  \item{swgt}{the size-weight for each site, which is the stage two size-weight 
    for a two-stage sample.  The default is NULL.}
  \item{swgt1}{the stage one size-weight for each site.  The default is NULL.}
  \item{unitsize}{the known sum of the size-weights of the resource, which for a 
    stratified sample must be a vector containing a value for each stratum 
    and must have the names attribute set to identify the stratum codes.  
    The default is NULL.}
  \item{vartype}{the choice of variance estimator, where "Local" = local mean
    estimator and "SRS" = SRS estimator.  The default is "Local".}
  \item{conf}{the confidence level.  The default is 95\%.}
  \item{check.ind}{a logical value that indicates whether compatability
    checking of the input values is conducted, where TRUE = conduct 
    compatibility checking and FALSE = do not conduct compatibility 
    checking.  The default is TRUE.}
}
\details{
  The Horvitz-Thompson estimator is used to calculate the total, variance, and 
  standard deviation estimates.  The Horvitz-Thompson ratio estimator, i.e., the 
  ratio of two Horvitz-Thompson estimators, is used to calculate the mean 
  estimate.  Variance estimates are calculated using either the local mean 
  variance estimator or the simple random sampling (SRS) variance 
  estimator.  The choice of variance estimator is subject to user control.  The 
  local mean variance estimator requires the x-coordinate and the 
  y-coordinate of each site.  The SRS variance estimator uses the 
  independent random sample approximation to calculate joint inclusion 
  probabilities.  Confidence bounds are calculated using a Normal 
  distribution multiplier.  The function can accommodate a stratified sample.  
  For a stratified sample, separate estimates and standard errors are calculated 
  for each stratum, which are used to produce estimates and standard errors for 
  all strata combined.  Strata that contain a single value are removed.  For a 
  stratified sample, when either the size of the resource or the sum of the size-
  weights of the resource is provided for each stratum, those values are used as 
  stratum weights for calculating the estimates and standard errors for all 
  strata combined.  For a stratified sample when neither the size of the resource
  nor the sum of the size-weights of the resource is provided for each stratum, 
  estimated values are used as stratum weights for calculating the estimates and 
  standard errors for all strata combined.  The function can accomodate 
  single-stage and two-stage samples for both stratified and unstratified 
  sampling designs.  Finite population and continuous population correction 
  factors can be utilized in variance estimation.  The function checks for 
  compatibility of input values and removes missing values.
}
\value{
  A data frame containing the estimates and confidence bounds.
}
\references{
  Diaz-Ramos, S., D.L. Stevens, Jr., and A.R. Olsen. (1996).  \emph{EMAP
  Statistical Methods Manual.} EPA/620/R-96/XXX.  Corvallis, OR: U.S.
  Environmental Protection Agency, Office of Research and Development, National
  Health Effects and Environmental Research Laboratory, Western Ecology
  Division.
}
\author{Tom Kincaid \email{Kincaid.Tom@epa.gov}}
\examples{
z <- rnorm(100, 10, 1)
wgt <- runif(100, 10, 100)
total.est.fcn(z, wgt, vartype="SRS")

\dontshow{software.program <- "R"}
x <- runif(100)
y <- runif(100)
total.est.fcn(z, wgt, x, y)
}
\keyword{survey}
\keyword{univar}

\eof
\name{write.object.fcn}
\alias{write.object.fcn}
\title{Write an Object to a Plot}
\description{
  This function writes an object, either a data frame or a matrix, to a plot.
}
\usage{
write.object.fcn(obj, n.digits=2, r.names=TRUE, c.names=TRUE,
  r.cex=1, c.cex=1, miss="NA")
}
\arguments{
  \item{obj}{the object (either a data frame or a matrix).}
  \item{n.digits}{the number of digits after the decimal point for numeric
    values.  The default is 2.}
  \item{r.names}{a logical value that indicates whether to print the row names,
    where TRUE = print the row names and  FALSE = do not print the row names.
    The default is TRUE.}
  \item{c.names}{a logical value that indicates whether to print the column
    names, where TRUE = print the column names and  FALSE = do not print the
    column names.  The default is TRUE.}
  \item{r.cex}{character expansion parameter for the row labels.  The default is
    1.}
  \item{c.cex}{character expansion parameter for the column labels.  The default
    is 1.}
  \item{miss}{the missing value code expressed as a character string.  The
    default is "NA".}
}
\value{
  NULL
}
\author{Tom Kincaid \email{Kincaid.Tom@epa.gov}}
\examples{
z <- rnorm(100)
z.mean <- c(tapply(z, rep(1:4, rep(25,4)), mean), mean(z))
z.sd <- sqrt(c(tapply(z, rep(1:4, rep(25,4)), var), var(z)))
z.upper <- z.mean+1.96*z.sd
z.lower <- z.mean-1.96*z.sd
obj <- data.frame(rbind(z.mean, z.sd, z.upper, z.lower))
dimnames(obj) <- list(c("Mean Estimate", "Standard Deviation",
  "Lower 95\% Conf. Bound", "Upper 95\% Conf. Bound"), c(
  paste("Stratum", 1:4, sep=""), "AllStrata"))
write.object.fcn(obj, n.digits=3, r.cex=0.75)

obj <- data.frame(matrix(round(5 + runif(30), 1), nrow=6))
colnames(obj) <- c("United.States", "Russia", "Germany",
  "Japan", "France")
write.object.fcn(obj, n.digits=1, r.names=FALSE)
}
\keyword{aplot}

\eof
